# Creating Calibration Curves
Calibration curves are necessary if you want to quantify the concentration of unknown species. For TIC data this means a calibration curve for every species. For FID data, one can use correction factors\cite{Faiola_2012,Kim_2014} or advanced approaches such as the [polyarc](http://www.activatedresearch.com/Public_Documents/PA_FlavorAnalysis_AppNote_1627.pdf) which converts all species to methane before sending it to the detector. 

We will use the simpliest case where a calibration curve is available for each component. The data you will need to provide is a .csv with the first column containing the name of the species and the subsequent columns containing the concentrations for the respective standard vial. The .csv can be imported and viewed using the lines of code below:

*ALL CONCENTRATIONS SHOULD BE ENTERED IN CONSISTENT UNTIS, COMMMONLY MOLAR (mol/L)*

```import pandas as pd
standards = pd.read_csv('data/standards.csv')
standards.head()```

library_id|FA03.D|FA04.D|FA05.D
---|---|---|---
Methyl palmitate|0.25|0.5|1
Methyl heptadecanoate|0.25|0.5|1
Methyl docosanoate|0.25|0.5|1
Methyl undecanoate|0.25|0.5|1
Methyl cis-8,11,14-eicosatrienoate|0.25|0.5|1

With the concentration data available, we can now calculate the response factor (i.e. slope) for each species.

```from valence.analyze import std_curves
curves = std_curves(comp,stnd)
curves.head()```

library_id|responsefactor|intercept|rvalue|pvalue|stderr|max|min
---|---|---|---|---|---|---|---
Methyl linoleate|3.727e-08|-0.215|0.982|0.122|7.234e-09|31474938|11356919
Methyl myristate|7.870e-08|0.035|0.985|0.016|9.802e-09|11874993|1821171
Methyl arachidate|7.146e-08|-0.064|0.999|0.027|3.074e-09|14785000|4222622

We can also look at the fit for a specific species:

```import numpy as np
species = 'Methyl palmitate'
x = list(stnd[stnd.library_id==species].loc[0].values)[1:]
y = list(conc[conc.library_id==species].area[0:3].values)```

```fit = np.polyfit(x,y,1)
fit_fn = np.poly1d(fit)
plt.plot(x,y, 'o', x, fit_fn(x), '--k')```