# Reporting and Plotting Data
All of the analysis is done and can be archived to a couple .csv files for later use. Before saving lets put the determined concentrations in a pivot table and make a couple plots for reporting purposes.

```pd.pivot_table(conc.reset_index(),
               index='library_id',
               columns='key',
               values='conc')```

library_id|FA08.D|FA09.D|FA11.D|FA12.D|FA13.D|FA14.D
---|---|---|---|---|---|---
Methyl linolelaidate||||||
Methyl myristate|||||0.055|
Methyl palmitate|||0.1|0.267|0.271|0.251
Methyl palmitoleate|||0.094|0.174|0.306|0.16
Methyl stearate||||||
cis-10-Pentadecenoic acid methyl ester|2.175|3.326||||
cis-9-Oleic methyl ester||||||

There several great plotting packages available in python. Here we will use Bokeh to show three plots:

1. Bar chart of normalized stacked concentrations
2. Bar chart of stacked concentrations
3. Bar chart of concentrations

The code to produce the plots are shown below as an example of what can be done to produce publication quality plots.

```from bokeh.charts import Bar, show, output_notebook, output_file
from bokeh.layouts import gridplot
output_notebook()
output_file("barplots.html")```

```one = Bar(conc.reset_index(),
                       label ='key',
                       values = 'conc%',
                       agg='sum',
                       stack='library_id',
                       title = 'Concentration% - Stacked',
                       legend = False)
two = Bar(conc.reset_index(),
                       label ='key',
                       values = 'conc',
                       agg='sum',
                       stack='library_id',
                       title = 'Concentration% - Sum',
                       legend = None)
three = Bar(conc.reset_index(),
                       label ='key',
                       values = 'conc',
                       group = 'library_id',
                       title = 'Concentration',
                       legend = 'top_right',
                       height = 300)
one.yaxis.axis_label = 'conc%'
two.yaxis.axis_label = 'conc'
three.yaxis.axis_label = 'conc'
three.legend.label_text_font_size= "0.75em"
three.legend.label_text_font_style = "bold"
p = gridplot([one,two,three],
             ncols=2,
             sizing_mode='scale_width')
show(p)```